@@ -126,14 +126,14 @@ class ViewSet(viewsets.ViewSet):
         return serializer.validated_data
 
     @classmethod
-    def _simplify_errors(cls, errors):
+    def simplify_errors(cls, errors):
         if isinstance(errors, dict):
-            return {attr: cls._simplify_errors(errs) for attr, errs in errors.items()}
+            return {attr: cls.simplify_errors(errs) for attr, errs in errors.items()}
         if isinstance(errors, list) and isinstance(errors[0], dict):
             # Simplify many to many relations errors
             many2many_errors = []
             for item_errors in errors:
-                many2many_errors.append(cls._simplify_errors(item_errors))
+                many2many_errors.append(cls.simplify_errors(item_errors))
             return many2many_errors
         return str(errors[0])
 
@@ -165,7 +165,7 @@ class ViewSet(viewsets.ViewSet):
         try:
             validated_data = self.get_validated_data(**kwargs)
         except ValidationError as e:
-            errors = self._simplify_errors(e.detail)
+            errors = self.simplify_errors(e.detail)
             raise exceptions.ValidationError(errors)
         return dict(validated_data)
 
@@ -175,7 +175,7 @@ class ViewSet(viewsets.ViewSet):
                 serializer_key=serializer_key, many=True
             )
         except ValidationError as e:
-            errors = self._simplify_errors(e.detail)
+            errors = self.simplify_errors(e.detail)
             raise exceptions.ValidationError(errors)
         return list(validated_data)
 
@@ -229,12 +229,15 @@ class ModelServiceViewSet(ViewSet):
             **params:
                 - serializer_key: serializer to use (default: action name)
                 - status_code: default is status.HTTP_201_CREATED
+                - filter_by_query_params: filter or not optimized queryset
+                  by request's query params (default: True)
         Returns:
             Response
         """
         default = {
             "serializer_key": None,
             "status_code": status.HTTP_200_OK,
+            "filter_by_query_params": True,
         }
         params = {**default, **params}
 
@@ -243,7 +246,7 @@ class ModelServiceViewSet(ViewSet):
             queryset = self.service.list()
 
         optimized_queryset = serializer_class.get_optimized_queryset(queryset)
-        if self.request.query_params:
+        if params.get("filter_by_query_params") and self.request.query_params:
             optimized_queryset = optimized_queryset.filter(
                 **self.request.query_params.dict()
             )
