@@ -11,20 +11,23 @@ from w.services.technical.filesystem_service import FilesystemService
 class AbstractImportService(AbstractService):
     sheet_name = None
     _filename = None
+    _context = None
 
     @classmethod
-    def import_file(cls, filename) -> ImportReport:
+    def import_file(cls, filename, context=None) -> ImportReport:
         """
         Import filename
 
         Args:
             filename(str): csv or excel file
+            context(dict): context to use for subsequent methods
 
         Returns:
             Tuple[list, ImportReport]
         """
         FilesystemService.check_file_exists(filename)
         cls._filename = filename
+        cls._context = context
         data = cls._load_data(filename, cls._list_mapping_columns())
         return cls.import_data(data)
 
