@@ -2,6 +2,7 @@ import os
 from django.core.mail import EmailMessage
 from django.template.loader import render_to_string
 from django.conf import settings
+from django.utils import timezone
 
 from w.services.abstract_service import AbstractService
 
@@ -27,7 +28,8 @@ class EmailService(AbstractService):
                 {"attach_files": [<str>], "context": <dict> }
             **options (dict):
                     'from_email': <from_email, default is settings.DEFAULT_FROM_EMAIL>,
-                    'reply_to' : <reply to email, None by default>
+                    'reply_to' : <reply to email, None by default>,
+                    'send_on' : <date to send the mail, now by default>,
 
         Returns:
             int: number of email sent
@@ -46,6 +48,8 @@ class EmailService(AbstractService):
         if not isinstance(recipients, dict):
             recipients = {"to": recipients}
 
+        send_on = options.pop("send_on", timezone.now())
+
         # noinspection PyDictCreation
         params = {**default_params, **recipients, **options}
 
@@ -74,4 +78,6 @@ class EmailService(AbstractService):
             for file in attach_files:
                 email.attach_file(file)
 
+        email.send_on = send_on
+
         return email.send()
