@@ -1,7 +1,5 @@
 from w.tests.builders.abstract_test_builder import AbstractTestBuilder
-from w.tests.fixtures.datasets.builders.factory_boy import (
-    ExampleWithAutoNowFactory,
-)
+from w.tests.fixtures.datasets.builders.factory_boy import ExampleWithAutoNowFactory
 
 
 class BuilderWithAutoNow(AbstractTestBuilder):
